Generating QuickFIX Databases

# MySQL

You must have MySQL installed with the deamon running.

Run the create script in src/sql/mysql. You must pass in a mysql user with permissions authorized to create a new database.

    ./create.sh mysql

    create.bat mysql

# MSSQL

You must have MySQL installed with the deamon running.

Run the create script in src/sql/mssql. You must pass in a mssql user with permissions authorized to create a new database.

    create.bat sa

# PostgreSQL

You must have PostgreSQL installed with the deamon running.

Run the create script in src/sql/postgresql. You must pass in a postgresql user with permissions authorized to create a new database.

    ./create.sh postgres

    create.bat postgres